# -*- coding: utf-8 -*-
from loguru import logger as log
import uvicorn
from fastapi import FastAPI
import iscc_index
from iscc_index.config import ISCC_INDEX_ALLOWED_ORIGINS
from starlette.middleware.cors import CORSMiddleware
import iscc

app = FastAPI(
    title="ISCC Index API",
    version=iscc_index.__version__,
    description="Microservice for indexing and searching ISCC Codes.",
    docs_url="/",
)

app.add_middleware(
    CORSMiddleware,
    allow_origins=ISCC_INDEX_ALLOWED_ORIGINS,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)


@app.post("/add", tags=["add"])
def add(iscc_obj: iscc.ISCC):
    """Add an ISCC to the index."""
    key = app.state.index.add(iscc_obj)
    return {"added": key}


@app.post("/query", response_model=iscc.QueryResult, tags=["query"])
def add(iscc_obj: iscc.ISCC, k: int = 10, ct: int = 10, ft: int = 10):
    """Query ISCC for nearest neighbors."""
    qr = app.state.index.query(iscc_obj, k, ct, ft)
    return qr


@app.get("/stats", tags=["stats"])
def stats():
    """Return index statistics."""
    return app.state.index.stats


@app.on_event("startup")
async def on_startup():
    app.state.options = iscc.Options()
    log.info(app.state.options)
    app.state.index = iscc.Index()


def run_server():
    uvicorn.run("iscc_index.main:app", host="127.0.0.1", port=8090, reload=False)


if __name__ == "__main__":
    uvicorn.run("iscc_index.main:app", host="127.0.0.1", port=8090, reload=True)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['iscc_index']

package_data = \
{'': ['*']}

install_requires = \
['fastapi>=0.63.0,<0.64.0', 'iscc>=1.1.0b5,<2.0.0', 'uvicorn>=0.13.4,<0.14.0']

entry_points = \
{'console_scripts': ['iscc-index = iscc_index.main:run_server']}

setup_kwargs = {
    'name': 'iscc-index',
    'version': '1.1.0b5',
    'description': 'ISCC Index - Nearest Neighbor Search',
    'long_description': "# iscc-index - ISCC Nearest Neighbor Search\n\n> A REST OpenAPI Backend for indexing [**ISCC codes**](https://iscc.codes) for digital media files.\n\n\nThe Webservice is build with [FastAPI](https://github.com/tiangolo/fastapi) and makes\nuse of the [ISCC reference implementation](<https://github.com/iscc/iscc-specs>).\nIt includes an interactive API documentation:\n\n![Interactive ISCC Api Docs](screenshot.jpg)\n\n\nThe Docker image is published at https://hub.docker.com/r/titusz/iscc-index\n\n\n## Install via pip\n\n```bash\n$ pip3 install iscc-index\n```\n\nStart webservice via uvicorn\n\n```bash\n$ iscc-index\nINFO:     Started server process [18800]\nINFO:     Waiting for application startup.\nINFO:     Application startup complete.\nINFO:     Uvicorn running on http://127.0.0.1:8090 (Press CTRL+C to quit)\n```\n\n## Setup for development\n\nIf you are using [poetry](https://python-poetry.org/):\n\n- After checkout cd into code directory and run 'poetry install' to install dependencies.\n- Launch dev server with: 'uvicorn iscc_index.main:app --reload' or 'icscc-index'\n- See API docs at: http://127.0.0.1:8090\n\n\n## License\n\nMIT © 2021 Titusz Pan\n",
    'author': 'Titusz Pan',
    'author_email': 'tp@py7.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://iscc.codes/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.1,<3.10',
}


setup(**setup_kwargs)
